simpleproxy

package
v0.4.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 14, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Overview

Package simpleproxy supports plain authenticated HTTP proxy entries.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Proxy

type Proxy struct {
	Host     string
	Port     int
	Username string
	Password string
}

Proxy is a plain authenticated HTTP proxy endpoint.

func IPv4Range

func IPv4Range(proxy Proxy, start, end int) ([]Proxy, error)

IPv4Range expands a proxy by replacing its final IPv4 octet with each value in the inclusive range [start, end].

func Parse

func Parse(line string) (Proxy, error)

Parse parses ip:port:username:password proxy entries.

func ParseLines

func ParseLines(lines string) ([]Proxy, error)

ParseLines parses newline-separated proxy entries, ignoring blank lines.

func (Proxy) URL

func (p Proxy) URL() *url.URL

URL returns an authenticated HTTP proxy URL.

Jump to